% ---------------------------------------------------------------
% CM=ConditionNumbers(n)
%
% Return the condition number of projection Basises obtained
% with function MomentsBasis up to order a,n.
% (projection Basises up to size (a,n))
%
% Input parameters:
%      > a: Image size
%      > n: Maximum number of colums of the projection Basis.
%
% Output parameters:
%      > N: Vector with the condition numbers for increasing number of
%           columns in the projection Basis up to n.
%
% ---------------------------------------------------------------
function [Cm,Cmm,Cc,Cf,Ch,Rcm,Rfm,Rhm]=ConditionNumbers(a,n)
  % Condition numbers of the moment matrices
  Cm(1)=log(cond(MomentsBasis(a,a)));

  % condition numbers of M' * M
  % This is used in lemma 1 for reconstruction.
  for i=1:n
    Cmm(i)=log(cond(MomentsBasis(a,i)'*MomentsBasis(a,i)));
  end

  % condition numbers of M' * C .
  % This is used in lemma 1 for reconstruction.
  for i=1:n
    Cc(i)=log(cond(MomentsBasis(a,i)'*ChebyshevBasis(a,i)));
  end

  % condition numbers of M' * F
  % This is used in lemma 1 for reconstruction.
  for i=1:n
    Cf(i)=log(cond(MomentsBasis(a,i)'*FourierBasis(a,i)));
  end

  % condition numbers of M' * H
  % This is used in lemma 1 for reconstruction.
  b=2^(fix(log2(a)));
  for i=1:n
      Ch(i)=log(cond(MomentsBasis(b,i)'*HaarBasis(b,i)));
  end
  Rcm(1)=0;
  Rfm(1)=0;
  Rhm(1)=0;
  for i=2:n
    Rcm(i)=Cmm(i)/Cc(i);
    Rfm(i)=Cmm(i)/Cf(i);
    Rhm(i)=Cmm(i)/Ch(i);
  end
