% ---------------------------------------------------------------
% B=HaarBasis(b,n)
%
% Returns the base matrix to get the Haar coeficients of an image.
% This base matrix can be later used in the project/reconstruct functions.
%
% The notation 'b' and 'n' corresponds to the one used in the Project
% function. 'b' are the columns/rows of the input image and 'n' are the
% rows/columns of the coefficicient matrix.
%
% Input parameters:
%       > b: rows of B (number of elements per vector)
%       > n: columns of B (number of vectors in the base)
% Output parameters:
%       > B: The base matrix
%
% ---------------------------------------------------------------
function B=HaarBasis(b,n)
  if (fix(log2(b))~=log2(b))
    error('In the HaarBasis the number of rows (first parameter) must be power of 2');
  end

  B=zeros(b,n);
  for k=1:b
    B(k,1)=1;
  end

  for l=2:n
    r=2^fix(log2(l-1));
    length=b/r;
    start=((l-1)-r)*length+1;
    middle=start+length/2-1;
    last=start+length-1;
    v=sqrt(r);
    for k=start:middle
      B(k,l)=v;
    end
    for k=middle+1:last
      B(k,l)=-v;
    end
  end
  B=(1/sqrt(b))*B;
