% ---------------------------------------------------------------
% iB=InverseMomentsBasis(n)
%
% Returns the invers of a (n,n) moments basis matrix.
% The inverse is obtained in close form using the fact that
% the moments are a special case of the Vandermonde matrices
% with base v_i=i (see VandermondeMatrix.m).
%
% Attention!! the implementation here is the transpose of the
% one described in equation 10 of the paper 'Moment-preserving
% image approximations'
% This is because the MomentsBasis is the transposed of a
% special case of the VandermodeMatrix.
%
% Comb(i,j) is an extension of nchoosek (see Comp.m)
%
% Stirling are the Stirling numbers of the first kind.
%
% Input parameters:
%       > n: rows and colums of the output
% Output parameters:
%       > iB: The inverse moment matrix
%
% ---------------------------------------------------------------
function iB=InverseMomentsBasis(n)
  iB=zeros(n,n);

  for k=1:n
    for l=1:n
      s=0;
      for j=l:n
      	s=s+(((-1)^(j+1)*Comb(j,k)*Stirling(j,l))/factorial(j));
      end
      iB(l,k)=(-1)^(k+1)*k*s; % By assigning iB(l,k) and not iB(k,l) we get the transposed inverse
    end
  end


