% x=Kaczmarz(A,b,w,e)
%
% Solves a linear system A x = b via the Kaczmarz method.
%
% This is used from the KaczmarzInvert function
%
% Input parameters:
%       > A: (n,n) Matrix.
%       > b: (n,1) Vector.
%       > w: [0,1] the relaxation parameter (optional). 
%            Default to 1.0 (= no relaxation).
%       > e: The convergence criterion (change in X
%            to consider it has converged)
%            Default 0.00001
% Output parameters:
%       > x: (1,n) vector. The solution of the system.
%
% ---------------------------------------------------------------
function x=Kaczmarz(A,b,varargin)

  w=1.0;
  e=0.0001; 
  
  l=length(varargin);
  if l>0 w=varargin{1}; end
  if l>1 e=varargin{2}; end
  
  [m,n]=size(A);
  
  [mb,nb]=size(b);
  if mb~=m error('A-b number of rows missmatch in Kaczmarz'); end
  if nb~=1 error('Second argument (b) must be a vector in Kaczmarz'); end

  x=zeros(n,1); % Proof are given from x=0
  do 
    x1=x;
    for i=1:m
      a=A(i,:)'; %Get the i-th row of A and set it as a column vector 
      x = x - w * ((((x'*a) - b(i))/norm(a)^2) * a);
    end
    %ee=norm(x-x1)/norm(x)
  until (norm(x-x1)/norm(x)<e)
  ee=norm(x-x1)
  z=A * x  -b 
  norm(z)

  

  