% ---------------------------------------------------------------
% P=ProjectF(I,F,m,n)
%
% Projects an image I using the matrix base obtained with function F.
% Input parameters:
%       > I: Image to be projected. Matrix size (a,b)
%       > F: The function that generates the base matrix.
%            We must be able to call this function with 2 integer
%            arguments: F(a,m).
%            Predefined functions are :
%                - MomentsBasis
%                - ChebyshevBasis
%                - FourierBasis
%                - HaarBasis
%
%       > m: The rows of the coeficient matrix obatined after projection.
%       > n: The columns of the coeficient matrix obatined after projection.
%            This parameter is optional. If not given we produce a squared
%            coeficient matrix (n=m).
%
% Output parameters:
%       > P: The projection coefficients
%            Matrix size (m,n)
%
% This function is just a convenient wrapping of the Project function.
%
% Example of use:
%           ProjectF(I,@MomentsBasis,5)
%           ProjectF(I,@FourierBasis,10,5)
%
% ---------------------------------------------------------------
function P=ProjectF(I,F,m,varargin)
  l=length(varargin);
  if l>1
     error('Wrong number of arguments in ProjectF');
  else
     if l==0
       n=m;
     else
       n=varargin{1};
     end
  end

  [a,b]=size(I);

  B1=feval(F,a,m);
  B2=feval(F,b,n);

  P=Project(B1,I,B2);
